Package: breakDown
Title: Model Agnostic Explainers for Individual Predictions
Version: 0.2.2
Authors@R: c(person("Przemyslaw", "Biecek", email = "przemyslaw.biecek@gmail.com", role = c("aut", "cre")),
    person("Aleksandra", "Grudziaz", email = "aleksandra.grudziaz@gmail.com", role = "ctb"))
Description: Model agnostic tool for decomposition of predictions from black boxes.
    Break Down Table shows contributions of every variable to a final prediction. 
    Break Down Plot presents variable contributions in a concise graphical way. 
    This package work for binary classifiers and general regression models. 
Depends: R (>= 3.0)
Date: 2024-03-11
License: GPL-2
Encoding: UTF-8
LazyData: true
Imports: ggplot2
Suggests: knitr, rmarkdown, e1071, kernlab, xgboost, caret,
        randomForest, DALEX, ranger, testthat
VignetteBuilder: knitr
URL: https://pbiecek.github.io/breakDown/
BugReports: https://github.com/pbiecek/breakDown/issues
NeedsCompilation: no
Packaged: 2024-03-11 22:11:29 UTC; pbiecek
Author: Przemyslaw Biecek [aut, cre],
  Aleksandra Grudziaz [ctb]
Maintainer: Przemyslaw Biecek <przemyslaw.biecek@gmail.com>
Repository: CRAN
Date/Publication: 2024-03-11 23:30:02 UTC
Built: R 4.6.0; ; 2026-04-26 06:14:38 UTC; unix
